@@ -26,10 +26,17 @@
 # OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-__all__ = ["BadLines", "Checker" ,"InvalidPath", "Len8Error"]
+__all__ = [
+    "BadLines",
+    "Checker",
+    "Config",
+    "ConfigurationError",
+    "InvalidPath",
+    "Len8Error",
+]
 
 __productname__ = "len8"
-__version__ = "0.5.0"
+__version__ = "0.6.0"
 __description__ = "A utility for keeping line lengths within PEP 8 standards."
 __url__ = "https://github.com/parafoxia/len8"
 __docs__ = "https://len8.readthedocs.io/en/latest/"
@@ -38,5 +45,5 @@ __license__ = "BSD-3-Clause"
 __bugtracker__ = "https://github.com/parafoxia/len8/issues"
 __ci__ = "https://github.com/parafoxia/len8/actions"
 
-from .checker import Checker
+from .checker import Checker, Config
 from .errors import *
